@@ -1,5 +1,5 @@
 __all__ = ["pSock"]
-__version__ = "1.2.3"
+__version__ = "1.2.6"
 
 # -*- coding: utf-8 -*-
 
@@ -80,14 +80,9 @@ class LocalFunction:
                 return False
   
 class Web:
-    
-    def __init__(self):
-        self.response = None
-        self.responsedata = None
-    
-    def responsesearch(self, url, classandid = None):
-        self.response = requests.get(url)
-        soup = bs4.BeautifulSoup(self.response.text, "lxml")
+    def responsesearch(url, classandid = None):
+        response = requests.get(url)
+        soup = bs4.BeautifulSoup(response.text, "lxml")
         elements = ["!DOCTYPE","html","body","h1","h2","h3","h4","h5","h6","p","br","hr","acronym","abbr","address","b","bdo","big","blockquote","center","cite","code","del","dfn","em","font","i","ins","kbd","pre","q","s","samp","small","strike","strong","sub","sup","tt","u","var","xmp","form","input","textarea","button","select","optgroup","option","label","fieldset","legend","isindex","frame","frameset","noframe","iframe","img","map","area","a","link","ul","ol","li","dir","dl","dt","dd","table","caption","th","tr","td","thead","tbody","tfoot","col","colgroup","style","div","span","head","title","meta","base","basefont","script","noscript","applet","object","param"]
         if classandid == None:
             for element in elements:
@@ -107,21 +102,14 @@ class Web:
             raise SyntaxError(f"dict expected, not {type(classandid)}")
 
         
-    def getresponsedata(self, url):
-        response = self.response = requests.get(url).text
-        self.responsedata = json.loads(response)
-        return self.responsedata
+    def getresponsedata(url):
+        response = response = requests.get(url).text
+        responsedata = json.loads(response)
+        return responsedata
 
-    def getresponsetext(self, url):
-        response = self.response = requests.get(url)
+    def getresponsetext(url):
+        response = response = requests.get(url)
         return response.text
-    
-    @property
-    def responsemethod(self):
-        if self.response != None:
-            return self.response()
-        else:
-            raise OSError("Unable to convert in response class without execute getresponsetext().")
 
 class Net:
     def __init__(self, AddressFamily = AF_INET, Sock = SOCK_STREAM, Address = [None, None]):
