@@ -30,7 +30,7 @@
 
 """pSock is a socket / threading module that helps developers and students to approach Server-Client creation and much more."""
 
-import socket, psutil
+import socket, psutil, json, requests
 
 def getipconfig():
     af_map = {
@@ -40,6 +40,8 @@ def getipconfig():
     }
     n = 0
     data = {}
+    response = json.loads(requests.get("https://www.ipinfo.io").text)
+    data.update({"Address": [response["ip"], response["hostname"], [response["country"], response["region"], response["city"], response["loc"]], response["org"]]})
     for nick, addrs in psutil.net_if_addrs().items():
         if n == 0:
             nick = "Ethernet"
@@ -72,6 +74,12 @@ def getipconfigmap():
     psutil.AF_LINK: 'MAC',
     }
     n = 0
+    response = json.loads(requests.get("https://www.ipinfo.io").text)
+    print("Address:")
+    print("    IPv4 address   :    "+response["ip"])
+    print("    Hostname       :    "+response["hostname"])     
+    print("    Location       :    "+response["country"]+", "+response["region"]+", "+response["city"]+" | "+response["loc"])   
+    print("    Company        :    "+response["org"])
     for nick, addrs in psutil.net_if_addrs().items():
         if n == 0:
             print("Ethernet:")
@@ -93,7 +101,6 @@ def getipconfigmap():
             print("    %-4s" % af_map.get(addr.family, addr.family), end="")
             print(" address   : %s" % addr.address)
         n += 1
-            
 def gethostname():
     return socket.gethostname()
 
